@@ -83,6 +83,12 @@ my $email_to=[
 ##  WRITE "RESULT" SUBROUTINES HERE:
 ##  -------------------------------------------------------------
 
+sub hello_world {
+
+   print "\n   Net::FullAuto says \"HELLO WORLD!\"\n";
+
+}
+
 sub image_magick {
 
    # Check for installation
@@ -169,19 +175,65 @@ sub test_email {
 
 }
 
-sub hello_world {
-   open (FH,">briangreat.txt");
-   FH->autoflush(1);
-   my $cnt=0;
-   while (1) {
-      print FH $cnt++;
-#      sleep 2;
-      last if $cnt==20;
-   }
-   print "LOGIN SUCCESSFUL\n";
-   print FH "LOGIN SUCCESSFUL ",`date`,"\n";
-   close FH;
-   &cleanup();
+sub compare_fa_code {
+
+   my ($solaris,$laptop,$output,$stderr)=('','','','');
+   ($solaris_ssh,$stderr)=connect_ssh('Solaris');
+   ($solaris_sftp,$stderr)=connect_sftp('Solaris');
+   print "SFTP_CONNECT_STDERR=$stderr\n" if $stderr;
+   my $fa_code_p='/usr/local/lib/perl5/site_perl/5.12.1'.
+            '/Net/FullAuto/Custom/opens/Code/fa_code.pm';
+   ($output,$stderr)=$solaris_ssh->cmd("cp $fa_code_p /export/home/opens");
+   print "STDERR=$stderr\n" if $stderr;
+   ($output,$stderr)=$solaris_ssh->cmd(
+      "chown opens /export/home/opens/fa_code.pm");
+   print "STDERR=$stderr\n" if $stderr;
+   ($output,$stderr)=$solaris_sftp->lcd('/home/reedfish');
+   print "OUTPUT=$output\n" if $output;
+   print "STDERR=$stderr\n" if $stderr;
+   ($output,$stderr)=$solaris_sftp->get('fa_code.pm');
+   print "OUTPUT=$output\n" if $output;
+   print "STDERR=$stderr\n" if $stderr;
+   ($output,$stderr)=$solaris_ssh->cmd("rm /export/home/opens/fa_code.pm");
+   print "STDERR=$stderr\n" if $stderr;
+   ($output,$stderr)=$localhost->cmd(
+      "mv /home/reedfish/fa_code.pm /home/reedfish/fa_code.prod");
+   print "OUTPUT=$output\n" if $output;
+   print "STDERR=$stderr\n" if $stderr;
+   ($laptop_sftp,$stderr)=connect_sftp('Laptop');
+   ($output,$stderr)=$laptop_sftp->lcd('/home/reedfish');
+   print "OUTPUT=$output\n" if $output;
+   print "STDERR=$stderr\n" if $stderr;
+   my $fa_code_d='/usr/lib/perl5/site_perl/5.10'.
+            '/Net/FullAuto/Custom/KB06606/Code/fa_code.pm';
+   ($output,$stderr)=$laptop_sftp->get($fa_code_d);
+   print "OUTPUT=$output\n" if $output;
+   print "STDERR=$stderr\n" if $stderr;
+   ($output,$stderr)=$localhost->cmd(
+      "mv /home/reedfish/fa_code.pm /home/reedfish/fa_code.dev");
+   print "OUTPUT=$output\n" if $output;
+   print "STDERR=$stderr\n" if $stderr;
+   ($output,$stderr)=$localhost->cmd(
+      "diff /home/reedfish/fa_code.dev /home/reedfish/fa_code.prod > ".
+      "/home/reedfish/fa_code_dev_prod.diff");
+   print "OUTPUT=$output\n" if $output;
+   print "STDERR=$stderr\n" if $stderr;
+   ($output,$stderr)=$localhost->cmd(
+      "rm /home/reedfish/fa_code.prod /home/reedfish/fa_code.dev");
+   print "OUTPUT=$output\n" if $output;
+   print "STDERR=$stderr\n" if $stderr;
+   ($output,$stderr)=$laptop_sftp->cwd(
+      "/cygdrive/c/Documents and Settings/kb06606/Desktop/Compare fa_code.pm");
+   print "OUTPUT=$output\n" if $output;
+   print "STDERR=$stderr\n" if $stderr;
+   ($output,$stderr)=$laptop_sftp->put(
+      "/home/reedfish/fa_code_dev_prod.diff");
+   print "OUTPUT=$output\n" if $output;
+   print "STDERR=$stderr\n" if $stderr;
+   ($output,$stderr)=$localhost->cmd(
+       "rm /home/reedfish/fa_code_dev_prod.diff");
+   print "OUTPUT=$output\n" if $output;
+   print "STDERR=$stderr\n" if $stderr;
 }
 
 sub howdy_world {
